# AnalysisStatusResponseStatus

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**finished_at** | **str** | Datetime in ISO format informing about when the analysis has finished.  |
**reason** | **str** | Reasoning on finished run. |
**started_at** | **str** | Datetime in ISO format informing about when the analysis has started.  |
**state** | **str** |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

